Merge SegBo Phoneme and Metadata tables
================
Steven Moran
24 November, 2019

``` r
# Load SegBo CSV dumps from Google sheets
segbo.phonemes <- read.csv('../data/SegBo database - Phonemes.csv', na.strings = "", stringsAsFactors = FALSE)
segbo.metadata <- read.csv('../data/SegBo database - Metadata.csv', na.strings = "", stringsAsFactors = FALSE)
```

``` r
df <- left_join(segbo.phonemes, segbo.metadata, by=c("InventoryID"="InventoryID"))
glimpse(df)
```

    ## Observations: 1,666
    ## Variables: 17
    ## $ InventoryID                 <int> 1, 1, 2, 2, 2, 3, 3, 4, 4, 5, 6, 7, …
    ## $ BorrowingLanguageGlottocode <chr> "abau1245", "abau1245", "abui1241", …
    ## $ BorrowedSound               <chr> "t", "d̠ʒ", "ɟ", "ts", "ɡ", "d̠ʒ", "…
    ## $ SourceLanguageGlottocode    <chr> "tokp1240", "tokp1240", "stan1306, i…
    ## $ OnlyInLoanwords             <chr> "no", "yes", "yes", "yes", "yes", "y…
    ## $ Result                      <chr> "phonologization of allophone", "new…
    ## $ NewDistinction              <chr> "no", "affricate", "affricate", "aff…
    ## $ PhonemeComments             <chr> "allophone of /r/ in native phonolog…
    ## $ Verified                    <chr> NA, NA, "Eitan Grossman", "Eitan Gro…
    ## $ Glottocode                  <chr> "abau1245", "abau1245", "abui1241", …
    ## $ LanguageName                <chr> "Abau", "Abau", "Abui", "Abui", "Abu…
    ## $ BibTexKey                   <chr> "bailey1975abau", "bailey1975abau", …
    ## $ Filename                    <chr> NA, NA, NA, NA, NA, NA, NA, NA, NA, …
    ## $ Contributor                 <chr> "Einav Levanon", "Einav Levanon", "E…
    ## $ MetadataComments            <chr> NA, NA, NA, NA, NA, NA, NA, NA, NA, …
    ## $ PhoibleID                   <int> NA, NA, NA, NA, NA, NA, NA, NA, NA, …
    ## $ ClosestNeighbor             <lgl> NA, NA, NA, NA, NA, NA, NA, NA, NA, …

``` r
# Test that all of the Glottocodes match
expect_equal(nrow(df[which(df$Glottocode!=df$BorrowingLanguageGlottocode),] %>% select(InventoryID, BorrowingLanguageGlottocode, Glottocode, LanguageName, LanguageName)), 0)
```

``` r
# Test that all of the language names match
expect_equal(nrow(df[which(df$LanguageName!=df$BorrowingLanguageName),] %>% select(InventoryID, LanguageName, LanguageName)), 0)
```

``` r
# Test for any NA Glottocodes? in the BorrowingLanguageGlottocode field
expect_false(any(is.na(df$BorrowingLanguageGlottocode)))
```

``` r
# Write full table to disk
write.csv(df, file='../data/segbo_merged.csv', row.names = F)
```
